#
# spec file for package python-threadpoolctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-threadpoolctl
VCS: https://src.suse.de/SLFO-pool/python-threadpoolctl#f9514381d76ca9b66ffce00206f429d6505dc1447f2c404d68e7295783e9ebb2
Version:        3.5.0
Release:        160000.1.9
Summary:        Thread-pool Controls
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/joblib/threadpoolctl
Source:         https://files.pythonhosted.org/packages/source/t/threadpoolctl/threadpoolctl-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Python helpers to limit the number of threads used in native
libraries that handle their own internal threadpool (BLAS
and OpenMP implementations).

%prep
%setup -q -n threadpoolctl-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGES.md README.md
%license LICENSE
%{python_sitelib}/threadpoolctl.py
%pycache_only %{python_sitelib}/__pycache__/threadpoolctl.*.py*
%{python_sitelib}/threadpoolctl-%{version}*info

%changelog
* Thu May  2 2024 dmueller@suse.com
- update to 3.5.0:
  * Added support for the Scientific Python version of OpenBLAS
    which exposes symbols with different names than the ones
    of the original OpenBLAS library.
* Tue Apr  2 2024 dmueller@suse.com
- update to 3.4.0:
  * Added support for Python interpreters statically linked
    against libc or linked against alternative implementations
    of libc like musl
  * Added support for Pyodide
  * Extended FlexiBLAS support to be able to switch backend at
    runtime.
  * Added support for FlexiBLAS
  * Fixed a bug where an unsupported library would be detected
    because it shares a common prefix with one of the supported
    libraries. Now the symbols are also checked to
    identify the supported libraries.
* Fri Dec  8 2023 dmueller@suse.com
- update to 3.2.0:
  * Dropped support for Python 3.6 and 3.7.
  * Added support for custom library controllers. Custom
    controllers must inherit from the `threadpoolctl.LibController`
    class and be registered to threadpoolctl using the
    `threadpoolctl.register` function.
* Sat Jun 10 2023 ecsos@opensuse.org
- Add %%{?sle15_python_module_pythons}
* Mon Apr  3 2023 steven.kowalik@suse.com
- Add missing BuildRequires on numpy.
- Remove unneeded BuildRequires on pep517.
- Stop using python_sitelib/*.
* Sun Jul 24 2022 dmueller@suse.com
- update to 3.1.0:
  * Fixed a detection issue of the BLAS libraires packaged by conda-forge on Windows.
    https://github.com/joblib/threadpoolctl/pull/112
  * `threadpool_limits` and `ThreadpoolController.limit` now accept the string
    "sequential_blas_under_openmp" for the `limits` parameter. It should only be used for
    the specific case when one wants to have sequential BLAS calls within an OpenMP
    parallel region. It takes into account the unexpected behavior of OpenBLAS with the
    OpenMP threading layer.
* Sat Oct 16 2021 dmueller@suse.com
- update to 3.0.0:
  - New object `threadpooctl.ThreadpoolController` which holds controllers for all the
    supported native libraries. The states of these libraries is accessible through the
    `info` method (equivalent to `threadpoolctl.threadpool_info()`) and their number of
    threads can be limited with the `limit` method which can be used as a context
    manager (equivalent to `threadpoolctl.threadpool_limits()`).
  - Added support for OpenBLAS built for 64bit integers in Fortran.
  - Added the possibility to use `threadpoolctl.threadpool_limits` and
    `threadpooctl.ThreadpoolController` as decorators through their `wrap` method.
  - Fixed an attribute error when using old versions of OpenBLAS or BLIS that are
    missing version query functions.
  - Fixed an attribute error when python is run with -OO.
* Mon Jul 19 2021 dmueller@suse.com
- update to 2.2.0:
  - Report the architecture of the CPU cores detected by OpenBLAS
    (`openblas_get_corename`) in `threadpool_info()` and BLIS
    (`bli_arch_query_id` and `bli_arch_string`).
  - Fixed a bug when the version of MKL was not found. The
    "version" field is now set to None in that case.
    https://github.com/joblib/threadpoolctl/pull/82
- drop python_executable.patch (upstream)
* Fri Jul 24 2020 mcalabkova@suse.com
- update to 2.1.0
  * New commandline interface: 'python -m threadpoolctl -i numpy'
    will try to import the `numpy` package and then return the output of
    `threadpoolctl.threadpool_info()` on STDOUT formatted using the JSON
    syntax. This makes it easier to quickly introspect a Python environment.
- Add patch python_executable.patch
* Thu Mar  5 2020 pgajdos@suse.com
- initial version 2.0.0, required by python-joblib
